@@ -370,8 +370,8 @@ class Samples:
         else:
             raise TypeError("Flexible data type for X - Cannot compute histograms")
 
-    def merge_data(self,
-                   samp):
+    def merge(self,
+              samp):
         """
         Merge two sample sets together
         column and label names and orders should be the same in the two datasets
